@@ -1,3 +1,4 @@
+from .integromat import Integromat
 from .darkknight import DarkKnight
 from .ftp import Ftp
 from .ftps import Ftps
@@ -20,11 +21,12 @@ from airtable import Airtable
 from .zappier import Zappier
 from .ifttt import Ifttt
 
-__version__ = "0.14.0"
+__version__ = "0.15.1"
 
 darkknight = DarkKnight
 airtable = Airtable
 zappier = Zappier
+integromat = Integromat
 ifttt = Ifttt
 yahoo = Yahoo
 ftp = Ftp
